@@ -344,7 +344,7 @@
       });
 
       it('has array of listener protocols', function() {
-        expect(model.listenerProtocols).toEqual(['HTTP', 'TCP', 'TERMINATED_HTTPS']);
+        expect(model.listenerProtocols).toEqual(['HTTP', 'TCP', 'TERMINATED_HTTPS', 'HTTPS']);
       });
 
       it('has array of pool methods', function() {
@@ -590,7 +590,7 @@
       });
 
       it('should initialize listener protocols', function() {
-        expect(model.listenerProtocols.length).toBe(3);
+        expect(model.listenerProtocols.length).toBe(4);
         expect(model.listenerProtocols.indexOf('TERMINATED_HTTPS')).toBe(2);
       });
     });
@@ -641,7 +641,7 @@
       });
 
       it('should initialize listener protocols', function() {
-        expect(model.listenerProtocols.length).toBe(2);
+        expect(model.listenerProtocols.length).toBe(3);
         expect(model.listenerProtocols.indexOf('TERMINATED_HTTPS')).toBe(-1);
       });
     });
